opendaq package
===============

opendaq.daq module
------------------
Main functions used to communicate with the device.
See ``usage.rst`` for additional info.


.. automodule:: opendaq.daq
    :members:
    :undoc-members:
    :show-inheritance:
	
opendaq.experiment module
---------------------
Stream experiments definitions and shared methods.

.. automodule:: opendaq.experiment
    :members:
    :undoc-members:
    :show-inheritance:

Stream Experiments
^^^^^^^^^^^^^^^^^^
Stream experiments object creation

.. automodule:: opendaq.stream
    :members:
    :undoc-members:
    :show-inheritance:

External Experiments
^^^^^^^^^^^^^^^^^^^^
External experiments object creation

.. automodule:: opendaq.external
    :members:
    :undoc-members:
    :show-inheritance:
	
Burst Experiments
^^^^^^^^^^^^^^^^^
Burst experiments object creation

.. automodule:: opendaq.burst
    :members:
    :undoc-members:
    :show-inheritance:
	
	
opendaq.common module
---------------------
Common utils used in the rest of the modules.

.. automodule:: opendaq.common
    :members:
    :undoc-members:
    :show-inheritance:

opendaq.serial_sim module
-------------------------
Serial port simulator used for debug and tests.


.. automodule:: opendaq.serial_sim
    :members:
    :undoc-members:
    :show-inheritance:

opendaq.simulator module
------------------------
Function simulator, used to run the tests.


.. automodule:: opendaq.simulator
    :members:
    :undoc-members:
    :show-inheritance:
